@@ -50,42 +50,35 @@
 #include "../lib/logger.h"
 
 // We will pick the first cyclic group from this list that is
-// larger than the number of IPs in our whitelist. E.g. for an
+// larger than the number of IPs in our allowlist. E.g. for an
 // entire Internet scan, this would be cyclic32
 // Note: this list should remain ordered by size (primes) ascending.
 
-static cyclic_group_t groups[] = {
-{ // 2^8 + 1
-	.prime = 257,
-	.known_primroot = 3,
-	.prime_factors = {2},
-	.num_prime_factors = 1
-},
-{ // 2^16 + 1
-	.prime = 65537,
-	.known_primroot = 3,
-	.prime_factors = {2},
-	.num_prime_factors = 1
-},
-{ // 2^24 + 43
-	.prime = 16777259,
-	.known_primroot = 2,
-	.prime_factors = {2, 23, 103, 3541},
-	.num_prime_factors = 4
-},
-{ // 2^28 + 3
-	.prime = 268435459,
-	.known_primroot = 2,
-	.prime_factors = {2, 3, 19, 87211},
-	.num_prime_factors = 4
-},
-{ // 2^32 + 15
-	.prime = 4294967311,
-	.known_primroot = 3,
-	.prime_factors = {2, 3, 5, 131, 364289},
-	.num_prime_factors = 5
-}
-};
+static cyclic_group_t groups[] = {{// 2^8 + 1
+				   .prime = 257,
+				   .known_primroot = 3,
+				   .prime_factors = {2},
+				   .num_prime_factors = 1},
+				  {// 2^16 + 1
+				   .prime = 65537,
+				   .known_primroot = 3,
+				   .prime_factors = {2},
+				   .num_prime_factors = 1},
+				  {// 2^24 + 43
+				   .prime = 16777259,
+				   .known_primroot = 2,
+				   .prime_factors = {2, 23, 103, 3541},
+				   .num_prime_factors = 4},
+				  {// 2^28 + 3
+				   .prime = 268435459,
+				   .known_primroot = 2,
+				   .prime_factors = {2, 3, 19, 87211},
+				   .num_prime_factors = 4},
+				  {// 2^32 + 15
+				   .prime = 4294967311,
+				   .known_primroot = 3,
+				   .prime_factors = {2, 3, 5, 131, 364289},
+				   .num_prime_factors = 5}};
 
 #define COPRIME 1
 #define NOT_COPRIME 0
@@ -93,10 +86,15 @@ static cyclic_group_t groups[] = {
 // Check whether an integer is coprime with (p - 1)
 static int check_coprime(uint64_t check, const cyclic_group_t *group)
 {
-	for (unsigned i=0; i < group->num_prime_factors; i++) {
-		if (group->prime_factors[i] > check && !(group->prime_factors[i] % check)) {
+	if (check == 0 || check == 1) {
+		return NOT_COPRIME;
+	}
+	for (unsigned i = 0; i < group->num_prime_factors; i++) {
+		if (group->prime_factors[i] > check &&
+		    !(group->prime_factors[i] % check)) {
 			return NOT_COPRIME;
-		} else if (group->prime_factors[i] < check && !(check % group->prime_factors[i])) {
+		} else if (group->prime_factors[i] < check &&
+			   !(check % group->prime_factors[i])) {
 			return NOT_COPRIME;
 		} else if (group->prime_factors[i] == check) {
 			return NOT_COPRIME;
@@ -109,24 +107,33 @@ static int check_coprime(uint64_t check, const cyclic_group_t *group)
 // which is a generator of the additive group mod (p - 1)
 static uint32_t find_primroot(const cyclic_group_t *group, aesrand_t *aes)
 {
-	uint32_t candidate = (uint32_t) ((aesrand_getword(aes) & 0xFFFFFFFF) % group->prime);
-	if (candidate == 0) {
-		++candidate;
-	}
-	while (check_coprime(candidate, group) != COPRIME) {
-		++candidate;
-		//special case where we need to restart check from begin
-		if(candidate >= group->prime) { 
-			candidate = 1;
+	uint32_t candidate =
+	    (uint32_t)((aesrand_getword(aes) & 0xFFFFFFFF) % group->prime);
+	uint64_t retv = 0;
+
+	// The maximum primitive root we can return needs to be small enough such
+	// that there is no overflow when multiplied by any element in the largest
+	// group in ZMap, which currently has p = 2^{32} + 15.
+	const uint64_t max_root = (UINT64_C(1) << 32) - 14;
+
+	// Repeatedly find a generator until we hit one that is small enough. For
+	// the largest group, we have a very low probability of ever executing this
+	// loop more than once, and for small groups it will only execute once.
+	do {
+		// Find an element that is coprime in the additive group
+		while (check_coprime(candidate, group) != COPRIME) {
+			candidate += 1;
+			candidate %= group->prime;
 		}
-	}
-	uint64_t retv = isomorphism(candidate, group);
+		// Given a coprime element, apply the isomorphism.
+		retv = isomorphism(candidate, group);
+	} while (retv > max_root);
 	return retv;
 }
 
-const cyclic_group_t* get_group(uint64_t min_size)
+const cyclic_group_t *get_group(uint64_t min_size)
 {
-	for(unsigned i = 0; i < sizeof(groups); ++i) {
+	for (unsigned i = 0; i < sizeof(groups); ++i) {
 		if (groups[i].prime > min_size) {
 			return &groups[i];
 		}
@@ -135,17 +142,18 @@ const cyclic_group_t* get_group(uint64_t min_size)
 	assert(0);
 }
 
-cycle_t make_cycle(const cyclic_group_t* group, aesrand_t *aes)
+cycle_t make_cycle(const cyclic_group_t *group, aesrand_t *aes)
 {
 	cycle_t cycle;
 	cycle.group = group;
 	cycle.generator = find_primroot(group, aes);
-	cycle.offset = (uint32_t) (aesrand_getword(aes) & 0xFFFFFFFF);
+	cycle.offset = (uint32_t)(aesrand_getword(aes) & 0xFFFFFFFF);
 	cycle.offset %= group->prime;
+	cycle.order = group->prime - 1;
 	return cycle;
 }
 
-uint64_t isomorphism(uint64_t additive_elt, const cyclic_group_t* mult_group)
+uint64_t isomorphism(uint64_t additive_elt, const cyclic_group_t *mult_group)
 {
 	assert(additive_elt < mult_group->prime);
 	mpz_t base, power, prime, primroot;
@@ -154,8 +162,8 @@ uint64_t isomorphism(uint64_t additive_elt, const cyclic_group_t* mult_group)
 	mpz_init_set_ui(prime, mult_group->prime);
 	mpz_init(primroot);
 	mpz_powm(primroot, base, power, prime);
-	uint64_t retv = (uint64_t) mpz_get_ui(primroot);
-	log_trace("zmap", "Isomorphism: %llu", retv);
+	uint64_t retv = (uint64_t)mpz_get_ui(primroot);
+	log_debug("zmap", "Isomorphism: %llu", retv);
 	mpz_clear(base);
 	mpz_clear(power);
 	mpz_clear(prime);
