@@ -18,7 +18,7 @@
 
 int send_run_init(sock_t socket)
 {
-	(void) socket;
+	(void)socket;
 
 	// All init for pfring happens in get_socket
 	return 0;
@@ -27,16 +27,16 @@ int send_run_init(sock_t socket)
 int send_packet(sock_t sock, void *buf, int len, uint32_t idx)
 {
 	sock.pf.buffers[idx]->len = len;
-	memcpy(sock.pf.buffers[idx]->data, buf, len);
+	memcpy(pfring_zc_pkt_buff_data(sock.pf.buffers[idx], sock.pf.queue),
+	       buf, len);
 	int ret;
 	do {
-		ret = pfring_zc_send_pkt(sock.pf.queue, &sock.pf.buffers[idx], 0);
+		ret =
+		    pfring_zc_send_pkt(sock.pf.queue, &sock.pf.buffers[idx], 0);
 	} while (ret < 0);
 	return ret;
 }
 
-void send_finish(sock_t sock) {
-	pfring_zc_sync_queue(sock.pf.queue, tx_only);
-}
+void send_finish(sock_t sock) { pfring_zc_sync_queue(sock.pf.queue, tx_only); }
 
 #endif /* ZMAP_SEND_PFRING_H */
